# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_install import AppInstall

class TestAppInstall(unittest.TestCase):
    """AppInstall unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppInstall:
        """Test AppInstall
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppInstall`
        """
        model = AppInstall()
        if include_optional:
            return AppInstall(
                app_id = '',
                app_runner_config = nuon.models.app/app_runner_config.app.AppRunnerConfig(
                    app_id = '', 
                    app_runner_type = 'aws-ecs', 
                    created_at = '', 
                    created_by_id = '', 
                    env_vars = {
                        'key' : ''
                        }, 
                    id = '', 
                    org_id = '', 
                    updated_at = '', ),
                app_sandbox_config = nuon.models.app/app_sandbox_config.app.AppSandboxConfig(
                    app_id = '', 
                    connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        repo_name = '', 
                        repo_owner = '', 
                        updated_at = '', 
                        vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                            created_at = '', 
                            created_by_id = '', 
                            github_install_id = '', 
                            id = '', 
                            updated_at = '', 
                            vcs_connection_commit = [
                                nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                    author_email = '', 
                                    author_name = '', 
                                    component_config_connection_id = '', 
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    message = '', 
                                    sha = '', 
                                    updated_at = '', )
                                ], ), 
                        vcs_connection_id = '', ), 
                    created_at = '', 
                    created_by_id = '', 
                    id = '', 
                    org_id = '', 
                    public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        updated_at = '', ), 
                    sandbox_release = nuon.models.app/sandbox_release.app.SandboxRelease(
                        created_at = '', 
                        created_by_id = '', 
                        deprovision_policy_url = '', 
                        id = '', 
                        one_click_role_template_url = '', 
                        provision_policy_url = '', 
                        trust_policy_url = '', 
                        updated_at = '', 
                        version = '', ), 
                    sandbox_release_id = '', 
                    terraform_version = '', 
                    updated_at = '', 
                    variables = {
                        'key' : ''
                        }, ),
                aws_account = nuon.models.app/aws_account.app.AWSAccount(
                    created_at = '', 
                    created_by_id = '', 
                    iam_role_arn = '', 
                    id = '', 
                    region = '', 
                    updated_at = '', ),
                created_at = '',
                created_by_id = '',
                id = '',
                install_components = [
                    nuon.models.app/install_component.app.InstallComponent(
                        component = nuon.models.app/component.app.Component(
                            app_id = '', 
                            config_versions = 56, 
                            created_at = '', 
                            created_by_id = '', 
                            dependencies = [
                                ''
                                ], 
                            id = '', 
                            name = '', 
                            status = '', 
                            status_description = '', 
                            updated_at = '', ), 
                        component_id = '', 
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        install_deploys = [
                            nuon.models.app/install_deploy.app.InstallDeploy(
                                build_id = '', 
                                component_id = '', 
                                component_name = '', 
                                created_at = '', 
                                created_by_id = '', 
                                id = '', 
                                install_component_id = '', 
                                install_deploy_type = 'release', 
                                install_id = '', 
                                release_id = '', 
                                status = '', 
                                status_description = '', 
                                updated_at = '', )
                            ], 
                        install_id = '', 
                        updated_at = '', )
                    ],
                install_inputs = [
                    nuon.models.app/install_inputs.app.InstallInputs(
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        install_id = '', 
                        org_id = '', 
                        updated_at = '', 
                        values = {
                            'key' : ''
                            }, )
                    ],
                install_sandbox_runs = [
                    nuon.models.app/install_sandbox_run.app.InstallSandboxRun(
                        app_sandbox_config = nuon.models.app/app_sandbox_config.app.AppSandboxConfig(
                            app_id = '', 
                            connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                                branch = '', 
                                component_config_id = '', 
                                component_config_type = '', 
                                created_at = '', 
                                created_by_id = '', 
                                directory = '', 
                                id = '', 
                                repo = '', 
                                repo_name = '', 
                                repo_owner = '', 
                                updated_at = '', 
                                vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                                    created_at = '', 
                                    created_by_id = '', 
                                    github_install_id = '', 
                                    id = '', 
                                    updated_at = '', 
                                    vcs_connection_commit = [
                                        nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                            author_email = '', 
                                            author_name = '', 
                                            component_config_connection_id = '', 
                                            created_at = '', 
                                            created_by_id = '', 
                                            id = '', 
                                            message = '', 
                                            sha = '', 
                                            updated_at = '', )
                                        ], ), 
                                vcs_connection_id = '', ), 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            org_id = '', 
                            public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                                branch = '', 
                                component_config_id = '', 
                                component_config_type = '', 
                                created_at = '', 
                                created_by_id = '', 
                                directory = '', 
                                id = '', 
                                repo = '', 
                                updated_at = '', ), 
                            sandbox_release = nuon.models.app/sandbox_release.app.SandboxRelease(
                                created_at = '', 
                                created_by_id = '', 
                                deprovision_policy_url = '', 
                                id = '', 
                                one_click_role_template_url = '', 
                                provision_policy_url = '', 
                                trust_policy_url = '', 
                                updated_at = '', 
                                version = '', ), 
                            sandbox_release_id = '', 
                            terraform_version = '', 
                            updated_at = '', 
                            variables = {
                                'key' : ''
                                }, ), 
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        install_id = '', 
                        run_type = 'provision', 
                        status = '', 
                        status_description = '', 
                        updated_at = '', )
                    ],
                name = '',
                status = '',
                status_description = '',
                updated_at = ''
            )
        else:
            return AppInstall(
        )
        """

    def testAppInstall(self):
        """Test AppInstall"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.199
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json




from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from nuon.models.app_account import AppAccount
from nuon.models.app_docker_build_component_config import AppDockerBuildComponentConfig
from nuon.models.app_external_image_component_config import AppExternalImageComponentConfig
from nuon.models.app_helm_component_config import AppHelmComponentConfig
from nuon.models.app_job_component_config import AppJobComponentConfig
from nuon.models.app_terraform_module_component_config import AppTerraformModuleComponentConfig
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class AppComponentConfigConnection(BaseModel):
    """
    AppComponentConfigConnection
    """ # noqa: E501
    component_id: Optional[StrictStr] = None
    created_at: Optional[StrictStr] = None
    created_by: Optional[AppAccount] = None
    created_by_id: Optional[StrictStr] = None
    docker_build: Optional[AppDockerBuildComponentConfig] = None
    external_image: Optional[AppExternalImageComponentConfig] = None
    helm: Optional[AppHelmComponentConfig] = None
    id: Optional[StrictStr] = None
    job: Optional[AppJobComponentConfig] = None
    terraform_module: Optional[AppTerraformModuleComponentConfig] = None
    updated_at: Optional[StrictStr] = None
    version: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["component_id", "created_at", "created_by", "created_by_id", "docker_build", "external_image", "helm", "id", "job", "terraform_module", "updated_at", "version"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AppComponentConfigConnection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['created_by'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of docker_build
        if self.docker_build:
            _dict['docker_build'] = self.docker_build.to_dict()
        # override the default output from pydantic by calling `to_dict()` of external_image
        if self.external_image:
            _dict['external_image'] = self.external_image.to_dict()
        # override the default output from pydantic by calling `to_dict()` of helm
        if self.helm:
            _dict['helm'] = self.helm.to_dict()
        # override the default output from pydantic by calling `to_dict()` of job
        if self.job:
            _dict['job'] = self.job.to_dict()
        # override the default output from pydantic by calling `to_dict()` of terraform_module
        if self.terraform_module:
            _dict['terraform_module'] = self.terraform_module.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of AppComponentConfigConnection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "component_id": obj.get("component_id"),
            "created_at": obj.get("created_at"),
            "created_by": AppAccount.from_dict(obj.get("created_by")) if obj.get("created_by") is not None else None,
            "created_by_id": obj.get("created_by_id"),
            "docker_build": AppDockerBuildComponentConfig.from_dict(obj.get("docker_build")) if obj.get("docker_build") is not None else None,
            "external_image": AppExternalImageComponentConfig.from_dict(obj.get("external_image")) if obj.get("external_image") is not None else None,
            "helm": AppHelmComponentConfig.from_dict(obj.get("helm")) if obj.get("helm") is not None else None,
            "id": obj.get("id"),
            "job": AppJobComponentConfig.from_dict(obj.get("job")) if obj.get("job") is not None else None,
            "terraform_module": AppTerraformModuleComponentConfig.from_dict(obj.get("terraform_module")) if obj.get("terraform_module") is not None else None,
            "updated_at": obj.get("updated_at"),
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.168
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_app_aws_delegation_config import AppAppAWSDelegationConfig

class TestAppAppAWSDelegationConfig(unittest.TestCase):
    """AppAppAWSDelegationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAppAWSDelegationConfig:
        """Test AppAppAWSDelegationConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAppAWSDelegationConfig`
        """
        model = AppAppAWSDelegationConfig()
        if include_optional:
            return AppAppAWSDelegationConfig(
                access_key_id = '',
                app_sandbox_config_id = '',
                created_at = '',
                created_by = nuon.models.app/account.app.Account(
                    account_type = 'auth0', 
                    created_at = '', 
                    email = '', 
                    id = '', 
                    org_ids = [
                        ''
                        ], 
                    permissions = {
                        'key' : 'unknown'
                        }, 
                    roles = [
                        nuon.models.app/role.app.Role(
                            created_by = nuon.models.app/account.app.Account(
                                created_at = '', 
                                email = '', 
                                id = '', 
                                subject = '', 
                                updated_at = '', ), 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            policies = [
                                nuon.models.app/policy.app.Policy(
                                    created_at = '', 
                                    created_by = , 
                                    created_by_id = '', 
                                    id = '', 
                                    name = 'org_admin', 
                                    role_id = '', 
                                    updated_at = '', )
                                ], 
                            role_type = 'org_admin', 
                            updated_at = '', )
                        ], 
                    subject = '', 
                    updated_at = '', ),
                created_by_id = '',
                iam_role_arn = '',
                id = '',
                org_id = '',
                secret_access_key = '',
                updated_at = ''
            )
        else:
            return AppAppAWSDelegationConfig(
        )
        """

    def testAppAppAWSDelegationConfig(self):
        """Test AppAppAWSDelegationConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
